@@ -8,6 +8,8 @@ import (
 	"runtime"
 	"strings"
 
+	"github.com/imdario/mergo"
+	"github.com/pkg/errors"
 	"github.com/sirupsen/logrus"
 	"github.com/urfave/cli"
 
@@ -16,6 +18,47 @@ import (
 	"gitlab.com/gitlab-org/gitlab-runner/network"
 )
 
+type configTemplate struct {
+	*common.Config
+
+	ConfigFile string `long:"config" env:"TEMPLATE_CONFIG_FILE" description:"Path to the configuration template file"`
+}
+
+func (c *configTemplate) Enabled() bool {
+	return c.ConfigFile != ""
+}
+
+func (c *configTemplate) MergeTo(config *common.RunnerConfig) error {
+	err := c.loadConfigTemplate()
+	if err != nil {
+		return errors.Wrap(err, "couldn't load configuration template file")
+	}
+
+	if len(c.Runners) != 1 {
+		return errors.New("configuration template must contain exactly one [[runners]] entry")
+	}
+
+	err = mergo.Merge(config, c.Runners[0])
+	if err != nil {
+		return errors.Wrap(err, "error while merging configuration with configuration template")
+	}
+
+	return nil
+}
+
+func (c *configTemplate) loadConfigTemplate() error {
+	config := common.NewConfig()
+
+	err := config.LoadConfig(c.ConfigFile)
+	if err != nil {
+		return err
+	}
+
+	c.Config = config
+
+	return nil
+}
+
 type RegisterCommand struct {
 	context    *cli.Context
 	network    common.Network
@@ -23,6 +66,9 @@ type RegisterCommand struct {
 	registered bool
 
 	configOptions
+
+	ConfigTemplate configTemplate `namespace:"template"`
+
 	TagList           string `long:"tag-list" env:"RUNNER_TAG_LIST" description:"Tag list"`
 	NonInteractive    bool   `short:"n" long:"non-interactive" env:"REGISTER_NON_INTERACTIVE" description:"Run registration unattended"`
 	LeaveRunner       bool   `long:"leave-runner" env:"REGISTER_LEAVE_RUNNER" description:"Don't remove runner if registration fails"`
@@ -217,6 +263,7 @@ func (s *RegisterCommand) askExecutorOptions() {
 	ssh := s.SSH
 	parallels := s.Parallels
 	virtualbox := s.VirtualBox
+	custom := s.Custom
 
 	s.Kubernetes = nil
 	s.Machine = nil
@@ -224,6 +271,7 @@ func (s *RegisterCommand) askExecutorOptions() {
 	s.SSH = nil
 	s.Parallels = nil
 	s.VirtualBox = nil
+	s.Custom = nil
 
 	executorFns := map[string]func(){
 		"kubernetes": func() {
@@ -273,10 +321,13 @@ func (s *RegisterCommand) askExecutorOptions() {
 			s.askSSHLogin()
 		},
 		"shell": func() {
-			if runtime.GOOS == "windows" {
+			if runtime.GOOS == "windows" && s.RunnerConfig.Shell == "" {
 				s.Shell = "powershell"
 			}
 		},
+		"custom": func() {
+			s.Custom = custom
+		},
 	}
 
 	executorFn, ok := executorFns[s.Executor]
@@ -331,12 +382,31 @@ func (s *RegisterCommand) Execute(context *cli.Context) {
 
 	s.askExecutor()
 	s.askExecutorOptions()
+
+	s.mergeTemplate()
+
 	s.addRunner(&s.RunnerConfig)
-	s.saveConfig()
+	err = s.saveConfig()
+	if err != nil {
+		logrus.Panicln(err)
+	}
 
 	logrus.Printf("Runner registered successfully. Feel free to start it, but if it's running already the config should be automatically reloaded!")
 }
 
+func (s *RegisterCommand) mergeTemplate() {
+	if !s.ConfigTemplate.Enabled() {
+		return
+	}
+
+	logrus.Infof("Merging configuration from template file %q", s.ConfigTemplate.ConfigFile)
+
+	err := s.ConfigTemplate.MergeTo(&s.RunnerConfig)
+	if err != nil {
+		logrus.WithError(err).Fatal("Could not handle configuration merging from template file")
+	}
+}
+
 func getHostname() string {
 	hostname, _ := os.Hostname()
 	return hostname
